@@ -1,5 +1,9 @@
 plot.pplace <-
-function(x,type="precise",simplify=FALSE,main="",N=NULL,transfo=NULL,legend=TRUE,stl=FALSE,asb=FALSE,edge.width=1,max_width=10,cex.number=0.5,cex.text=0.8,transp=80,add=FALSE,color=NULL,pch=16,...){
+function(x,type="precise",simplify=FALSE,main="",N=NULL,transfo=NULL,legend=TRUE,stl=FALSE,asb=FALSE,edge.width=1,max_width=10,cex.number=0.5,cex.text=0.8,transp=80,add=FALSE,color=NULL,discrete_col=FALSE,pch=16,run_id=NULL,...){
+
+  if(!is.null(run_id)){
+    x <- sub_pplace(x,run_id=run_id)
+  }
 
   if(is.null(N)){
     x$multiclass$N <- 1
@@ -9,14 +13,14 @@ function(x,type="precise",simplify=FALSE,main="",N=NULL,transfo=NULL,legend=TRUE
   }
   
   if(simplify){
-    x$placement <- x$placement[order(x$placement$ml_ratio,decreasing=TRUE),]
-    x$placement <- x$placement[match(unique(x$placement$placement_id),x$placement$placement_id),]
-    x$placement$ml_ratio <- 1
+    x$placement_positions <- x$placement_positions[order(x$placement_positions$ml_ratio,decreasing=TRUE),]
+    x$placement_positions <- x$placement_positions[match(unique(x$placement_positions$placement_id),x$placement_positions$placement_id),]
+    x$placement_positions$ml_ratio <- 1
   }
   
   if(type!="precise"){
     placement_N <- aggregate(x$multiclass$N,list(x$multiclass$placement_id),sum)
-    br_sum <- aggregate(placement_N[match(x$placement$placement_id,placement_N[,1]),2]*x$placement$ml_ratio,list(branch=x$placement$location),sum)
+    br_sum <- aggregate(placement_N[match(x$placement_positions$placement_id,placement_N[,1]),2]*x$placement_positions$ml_ratio,list(branch=x$placement_positions$location),sum)
 
     if(type=="number"){
       plot(x$arbre,edge.width=edge.width,show.tip.label=stl,no.margin=TRUE)
@@ -65,20 +69,27 @@ function(x,type="precise",simplify=FALSE,main="",N=NULL,transfo=NULL,legend=TRUE
     }
     if(asb) add.scale.bar()
     pos_phylo <- get_edge()
-    xpos <- pos_phylo[x$placement$location,1] + x$placement$distal_bl
-    ypos <- pos_phylo[x$placement$location,2]
+    xpos <- pos_phylo[x$placement_positions$location,1] + x$placement_positions$distal_bl
+    ypos <- pos_phylo[x$placement_positions$location,2]
     
-    if(length(color)==0){
-      col_palette=rgb(colorRamp(c("blue","green","yellow","red"))(seq(0,1,length=1000)), maxColorValue = 255)
-      vcol <- col_palette[ceiling((x$placement$pendant_bl/max(x$placement$pendant_bl))*1000)]
-    }
-    if(length(color)>0){
-      col_palette=rgb(colorRamp(color)(seq(0,1,length=1000)), maxColorValue = 255)
-      vcol <- col_palette[ceiling((x$placement$pendant_bl/max(x$placement$pendant_bl))*1000)]
+    if(is.null(color)) color <- c("blue","green","yellow","red")
+    
+    col_palette <- rgb(colorRamp(color)(seq(0,1,length=1000)), maxColorValue = 255)
+
+    if(discrete_col){
+      col_palette <- rep(NA,1000)
+      color <- col2rgb(color)
+      color <- apply(color,2,function(X){rgb(X[1],X[2],X[3], maxColorValue=255)})
+      pos_col <- round(seq(1,1000,length.out=length(color)+1))
+      for(i in 1:length(color)){
+	col_palette[pos_col[i]:pos_col[i+1]] <- color[i]
+      }
     }
+    vcol <- col_palette[ceiling((x$placement_positions$pendant_bl/max(x$placement_positions$pendant_bl))*1000)]
+    
     placement_N <- aggregate(x$multiclass$N,list(x$multiclass$placement_id),sum)
-    pos_id <- match(placement_N[,1],x$placement$placement_id)
-    cex_placement <- placement_N[match(x$placement$placement_id,placement_N[,1]),2]*x$placement$ml_ratio
+    pos_id <- match(placement_N[,1],x$placement_positions$placement_id)
+    cex_placement <- placement_N[match(x$placement_positions$placement_id,placement_N[,1]),2]*x$placement_positions$ml_ratio
     cex_placement[is.na(cex_placement)] <- 0
 
 	if(!is.null(transfo)) cex_placement <- transfo(cex_placement)
@@ -89,7 +100,7 @@ function(x,type="precise",simplify=FALSE,main="",N=NULL,transfo=NULL,legend=TRUE
     if(legend){
 	par(mar=c(3,7,3,3.5))
 	image(1:length(col_palette),1:1,matrix(1:length(col_palette),ncol=1),col=col_palette,xaxt="n",yaxt="n",xlab="",ylab="",main="pendant branch length",cex.main=1,font.main=1)
-	axis(3,at=c(1,length(col_palette)),labels=c(0,round(max(x$placement$pendant_bl),2)))
+	axis(3,at=c(1,length(col_palette)),labels=c(0,round(max(x$placement_positions$pendant_bl),2)))
 	par(mar=c(1,3.5,1,7))
 	plot.new()
 	cex_legend <- seq(0,ceiling(max(cex_placement)),length.out=5)
@@ -101,6 +112,7 @@ function(x,type="precise",simplify=FALSE,main="",N=NULL,transfo=NULL,legend=TRUE
 }
 
 plot.jplace <- function(x,...){
+	if(ncol(x$placement_positions)==7) colnames(x$placement_positions)[1:7] <- c("placement_id","location","ml_ratio","log_like","distal_bl","pendant_bl","tax_id")
+	if(ncol(x$placement_positions)==6) colnames(x$placement_positions)[1:6] <- c("placement_id","location","ml_ratio","log_like","distal_bl","pendant_bl")	
 	plot.pplace(x,...)
 }
-
